# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ByteBuffer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'char': 'str',
        'direct': 'bool',
        'double': 'float',
        '_float': 'float',
        '_int': 'int',
        'long': 'int',
        'read_only': 'bool',
        'short': 'int'
    }

    attribute_map = {
        'char': 'char',
        'direct': 'direct',
        'double': 'double',
        '_float': 'float',
        '_int': 'int',
        'long': 'long',
        'read_only': 'readOnly',
        'short': 'short'
    }

    def __init__(self, char=None, direct=None, double=None, _float=None, _int=None, long=None, read_only=None, short=None):  # noqa: E501
        """ByteBuffer - a model defined in Swagger"""  # noqa: E501
        self._char = None
        self._direct = None
        self._double = None
        self.__float = None
        self.__int = None
        self._long = None
        self._read_only = None
        self._short = None
        self.discriminator = None
        if char is not None:
            self.char = char
        if direct is not None:
            self.direct = direct
        if double is not None:
            self.double = double
        if _float is not None:
            self._float = _float
        if _int is not None:
            self._int = _int
        if long is not None:
            self.long = long
        if read_only is not None:
            self.read_only = read_only
        if short is not None:
            self.short = short

    @property
    def char(self):
        """Gets the char of this ByteBuffer.  # noqa: E501


        :return: The char of this ByteBuffer.  # noqa: E501
        :rtype: str
        """
        return self._char

    @char.setter
    def char(self, char):
        """Sets the char of this ByteBuffer.


        :param char: The char of this ByteBuffer.  # noqa: E501
        :type: str
        """

        self._char = char

    @property
    def direct(self):
        """Gets the direct of this ByteBuffer.  # noqa: E501


        :return: The direct of this ByteBuffer.  # noqa: E501
        :rtype: bool
        """
        return self._direct

    @direct.setter
    def direct(self, direct):
        """Sets the direct of this ByteBuffer.


        :param direct: The direct of this ByteBuffer.  # noqa: E501
        :type: bool
        """

        self._direct = direct

    @property
    def double(self):
        """Gets the double of this ByteBuffer.  # noqa: E501


        :return: The double of this ByteBuffer.  # noqa: E501
        :rtype: float
        """
        return self._double

    @double.setter
    def double(self, double):
        """Sets the double of this ByteBuffer.


        :param double: The double of this ByteBuffer.  # noqa: E501
        :type: float
        """

        self._double = double

    @property
    def _float(self):
        """Gets the _float of this ByteBuffer.  # noqa: E501


        :return: The _float of this ByteBuffer.  # noqa: E501
        :rtype: float
        """
        return self.__float

    @_float.setter
    def _float(self, _float):
        """Sets the _float of this ByteBuffer.


        :param _float: The _float of this ByteBuffer.  # noqa: E501
        :type: float
        """

        self.__float = _float

    @property
    def _int(self):
        """Gets the _int of this ByteBuffer.  # noqa: E501


        :return: The _int of this ByteBuffer.  # noqa: E501
        :rtype: int
        """
        return self.__int

    @_int.setter
    def _int(self, _int):
        """Sets the _int of this ByteBuffer.


        :param _int: The _int of this ByteBuffer.  # noqa: E501
        :type: int
        """

        self.__int = _int

    @property
    def long(self):
        """Gets the long of this ByteBuffer.  # noqa: E501


        :return: The long of this ByteBuffer.  # noqa: E501
        :rtype: int
        """
        return self._long

    @long.setter
    def long(self, long):
        """Sets the long of this ByteBuffer.


        :param long: The long of this ByteBuffer.  # noqa: E501
        :type: int
        """

        self._long = long

    @property
    def read_only(self):
        """Gets the read_only of this ByteBuffer.  # noqa: E501


        :return: The read_only of this ByteBuffer.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ByteBuffer.


        :param read_only: The read_only of this ByteBuffer.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def short(self):
        """Gets the short of this ByteBuffer.  # noqa: E501


        :return: The short of this ByteBuffer.  # noqa: E501
        :rtype: int
        """
        return self._short

    @short.setter
    def short(self, short):
        """Sets the short of this ByteBuffer.


        :param short: The short of this ByteBuffer.  # noqa: E501
        :type: int
        """

        self._short = short

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ByteBuffer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ByteBuffer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class NotificationRuleInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_config': 'NotificationRuleConfig',
        'created_time': 'int',
        'delivery_methods': 'list[str]',
        'id': 'NotificationRuleId',
        'enabled': 'bool',
        'name': 'str',
        'recipients_config': 'NotificationRuleRecipientsConfig',
        'template_id': 'NotificationTemplateId',
        'template_name': 'str',
        'tenant_id': 'TenantId',
        'trigger_config': 'NotificationRuleTriggerConfig',
        'trigger_type': 'str'
    }

    attribute_map = {
        'additional_config': 'additionalConfig',
        'created_time': 'createdTime',
        'delivery_methods': 'deliveryMethods',
        'id': 'id',
        'enabled': 'enabled',
        'name': 'name',
        'recipients_config': 'recipientsConfig',
        'template_id': 'templateId',
        'template_name': 'templateName',
        'tenant_id': 'tenantId',
        'trigger_config': 'triggerConfig',
        'trigger_type': 'triggerType'
    }

    def __init__(self, additional_config=None, created_time=None, delivery_methods=None, id=None, enabled=None, name=None, recipients_config=None, template_id=None, template_name=None, tenant_id=None, trigger_config=None, trigger_type=None):  # noqa: E501
        """NotificationRuleInfo - a model defined in Swagger"""  # noqa: E501
        self._additional_config = None
        self._created_time = None
        self._delivery_methods = None
        self._id = None
        self._enabled = None
        self._name = None
        self._recipients_config = None
        self._template_id = None
        self._template_name = None
        self._tenant_id = None
        self._trigger_config = None
        self._trigger_type = None
        self.discriminator = None
        if additional_config is not None:
            self.additional_config = additional_config
        if created_time is not None:
            self.created_time = created_time
        if delivery_methods is not None:
            self.delivery_methods = delivery_methods
        if id is not None:
            self.id = id
        if enabled is not None:
            self.enabled = enabled
        self.name = name
        self.recipients_config = recipients_config
        self.template_id = template_id
        if template_name is not None:
            self.template_name = template_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.trigger_config = trigger_config
        self.trigger_type = trigger_type

    @property
    def additional_config(self):
        """Gets the additional_config of this NotificationRuleInfo.  # noqa: E501


        :return: The additional_config of this NotificationRuleInfo.  # noqa: E501
        :rtype: NotificationRuleConfig
        """
        return self._additional_config

    @additional_config.setter
    def additional_config(self, additional_config):
        """Sets the additional_config of this NotificationRuleInfo.


        :param additional_config: The additional_config of this NotificationRuleInfo.  # noqa: E501
        :type: NotificationRuleConfig
        """

        self._additional_config = additional_config

    @property
    def created_time(self):
        """Gets the created_time of this NotificationRuleInfo.  # noqa: E501


        :return: The created_time of this NotificationRuleInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this NotificationRuleInfo.


        :param created_time: The created_time of this NotificationRuleInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def delivery_methods(self):
        """Gets the delivery_methods of this NotificationRuleInfo.  # noqa: E501


        :return: The delivery_methods of this NotificationRuleInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._delivery_methods

    @delivery_methods.setter
    def delivery_methods(self, delivery_methods):
        """Sets the delivery_methods of this NotificationRuleInfo.


        :param delivery_methods: The delivery_methods of this NotificationRuleInfo.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["EMAIL", "MICROSOFT_TEAMS", "SLACK", "SMS", "WEB"]  # noqa: E501
        if not set(delivery_methods).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `delivery_methods` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(delivery_methods) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._delivery_methods = delivery_methods

    @property
    def enabled(self):
        """Gets the enabled of this NotificationRuleInfo.  # noqa: E501


        :return: The enabled of this NotificationRuleInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this NotificationRuleInfo.


        :param enabled: The enabled of this NotificationRuleInfo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, id):
        self._id = id

    @property
    def name(self):
        """Gets the name of this NotificationRuleInfo.  # noqa: E501


        :return: The name of this NotificationRuleInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NotificationRuleInfo.


        :param name: The name of this NotificationRuleInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def recipients_config(self):
        """Gets the recipients_config of this NotificationRuleInfo.  # noqa: E501


        :return: The recipients_config of this NotificationRuleInfo.  # noqa: E501
        :rtype: NotificationRuleRecipientsConfig
        """
        return self._recipients_config

    @recipients_config.setter
    def recipients_config(self, recipients_config):
        """Sets the recipients_config of this NotificationRuleInfo.


        :param recipients_config: The recipients_config of this NotificationRuleInfo.  # noqa: E501
        :type: NotificationRuleRecipientsConfig
        """
        if recipients_config is None:
            raise ValueError("Invalid value for `recipients_config`, must not be `None`")  # noqa: E501

        self._recipients_config = recipients_config

    @property
    def template_id(self):
        """Gets the template_id of this NotificationRuleInfo.  # noqa: E501


        :return: The template_id of this NotificationRuleInfo.  # noqa: E501
        :rtype: NotificationTemplateId
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this NotificationRuleInfo.


        :param template_id: The template_id of this NotificationRuleInfo.  # noqa: E501
        :type: NotificationTemplateId
        """
        if template_id is None:
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def template_name(self):
        """Gets the template_name of this NotificationRuleInfo.  # noqa: E501


        :return: The template_name of this NotificationRuleInfo.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this NotificationRuleInfo.


        :param template_name: The template_name of this NotificationRuleInfo.  # noqa: E501
        :type: str
        """

        self._template_name = template_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this NotificationRuleInfo.  # noqa: E501


        :return: The tenant_id of this NotificationRuleInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this NotificationRuleInfo.


        :param tenant_id: The tenant_id of this NotificationRuleInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def trigger_config(self):
        """Gets the trigger_config of this NotificationRuleInfo.  # noqa: E501


        :return: The trigger_config of this NotificationRuleInfo.  # noqa: E501
        :rtype: NotificationRuleTriggerConfig
        """
        return self._trigger_config

    @trigger_config.setter
    def trigger_config(self, trigger_config):
        """Sets the trigger_config of this NotificationRuleInfo.


        :param trigger_config: The trigger_config of this NotificationRuleInfo.  # noqa: E501
        :type: NotificationRuleTriggerConfig
        """
        if trigger_config is None:
            raise ValueError("Invalid value for `trigger_config`, must not be `None`")  # noqa: E501

        self._trigger_config = trigger_config

    @property
    def trigger_type(self):
        """Gets the trigger_type of this NotificationRuleInfo.  # noqa: E501


        :return: The trigger_type of this NotificationRuleInfo.  # noqa: E501
        :rtype: str
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, trigger_type):
        """Sets the trigger_type of this NotificationRuleInfo.


        :param trigger_type: The trigger_type of this NotificationRuleInfo.  # noqa: E501
        :type: str
        """
        if trigger_type is None:
            raise ValueError("Invalid value for `trigger_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ALARM", "ALARM_ASSIGNMENT", "ALARM_COMMENT", "API_USAGE_LIMIT", "DEVICE_ACTIVITY", "ENTITIES_LIMIT", "ENTITY_ACTION", "NEW_PLATFORM_VERSION", "RATE_LIMITS", "RULE_ENGINE_COMPONENT_LIFECYCLE_EVENT"]  # noqa: E501
        if trigger_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trigger_type` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger_type, allowed_values)
            )

        self._trigger_type = trigger_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationRuleInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationRuleInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class LwM2MServerSecurityConfigDefault(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'short_server_id': 'int',
        'bootstrap_server_is': 'bool',
        'host': 'str',
        'port': 'int',
        'security_host': 'str',
        'security_port': 'int',
        'client_hold_off_time': 'int',
        'server_public_key': 'str',
        'server_certificate': 'str',
        'bootstrap_server_account_timeout': 'int',
        'lifetime': 'int',
        'default_min_period': 'int',
        'notif_if_disabled': 'bool',
        'binding': 'str'
    }

    attribute_map = {
        'short_server_id': 'shortServerId',
        'bootstrap_server_is': 'bootstrapServerIs',
        'host': 'host',
        'port': 'port',
        'security_host': 'securityHost',
        'security_port': 'securityPort',
        'client_hold_off_time': 'clientHoldOffTime',
        'server_public_key': 'serverPublicKey',
        'server_certificate': 'serverCertificate',
        'bootstrap_server_account_timeout': 'bootstrapServerAccountTimeout',
        'lifetime': 'lifetime',
        'default_min_period': 'defaultMinPeriod',
        'notif_if_disabled': 'notifIfDisabled',
        'binding': 'binding'
    }

    def __init__(self, short_server_id=None, bootstrap_server_is=None, host=None, port=None, security_host=None, security_port=None, client_hold_off_time=None, server_public_key=None, server_certificate=None, bootstrap_server_account_timeout=None, lifetime=None, default_min_period=None, notif_if_disabled=None, binding=None):  # noqa: E501
        """LwM2MServerSecurityConfigDefault - a model defined in Swagger"""  # noqa: E501
        self._short_server_id = None
        self._bootstrap_server_is = None
        self._host = None
        self._port = None
        self._security_host = None
        self._security_port = None
        self._client_hold_off_time = None
        self._server_public_key = None
        self._server_certificate = None
        self._bootstrap_server_account_timeout = None
        self._lifetime = None
        self._default_min_period = None
        self._notif_if_disabled = None
        self._binding = None
        self.discriminator = None
        if short_server_id is not None:
            self.short_server_id = short_server_id
        if bootstrap_server_is is not None:
            self.bootstrap_server_is = bootstrap_server_is
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if security_host is not None:
            self.security_host = security_host
        if security_port is not None:
            self.security_port = security_port
        if client_hold_off_time is not None:
            self.client_hold_off_time = client_hold_off_time
        if server_public_key is not None:
            self.server_public_key = server_public_key
        if server_certificate is not None:
            self.server_certificate = server_certificate
        if bootstrap_server_account_timeout is not None:
            self.bootstrap_server_account_timeout = bootstrap_server_account_timeout
        if lifetime is not None:
            self.lifetime = lifetime
        if default_min_period is not None:
            self.default_min_period = default_min_period
        if notif_if_disabled is not None:
            self.notif_if_disabled = notif_if_disabled
        if binding is not None:
            self.binding = binding

    @property
    def short_server_id(self):
        """Gets the short_server_id of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Server short Id. Used as link to associate server Object Instance. This identifier uniquely identifies each LwM2M Server configured for the LwM2M Client. This Resource MUST be set when the Bootstrap-Server Resource has a value of 'false'. The values ID:0 and ID:65535 values MUST NOT be used for identifying the LwM2M Server.  # noqa: E501

        :return: The short_server_id of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._short_server_id

    @short_server_id.setter
    def short_server_id(self, short_server_id):
        """Sets the short_server_id of this LwM2MServerSecurityConfigDefault.

        Server short Id. Used as link to associate server Object Instance. This identifier uniquely identifies each LwM2M Server configured for the LwM2M Client. This Resource MUST be set when the Bootstrap-Server Resource has a value of 'false'. The values ID:0 and ID:65535 values MUST NOT be used for identifying the LwM2M Server.  # noqa: E501

        :param short_server_id: The short_server_id of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._short_server_id = short_server_id

    @property
    def bootstrap_server_is(self):
        """Gets the bootstrap_server_is of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Is Bootstrap Server or Lwm2m Server. The LwM2M Client MAY be configured to use one or more LwM2M Server Account(s). The LwM2M Client MUST have at most one LwM2M Bootstrap-Server Account. (*) The LwM2M client MUST have at least one LwM2M server account after completing the boot sequence specified.  # noqa: E501

        :return: The bootstrap_server_is of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: bool
        """
        return self._bootstrap_server_is

    @bootstrap_server_is.setter
    def bootstrap_server_is(self, bootstrap_server_is):
        """Sets the bootstrap_server_is of this LwM2MServerSecurityConfigDefault.

        Is Bootstrap Server or Lwm2m Server. The LwM2M Client MAY be configured to use one or more LwM2M Server Account(s). The LwM2M Client MUST have at most one LwM2M Bootstrap-Server Account. (*) The LwM2M client MUST have at least one LwM2M server account after completing the boot sequence specified.  # noqa: E501

        :param bootstrap_server_is: The bootstrap_server_is of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: bool
        """

        self._bootstrap_server_is = bootstrap_server_is

    @property
    def host(self):
        """Gets the host of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Host for 'No Security' mode  # noqa: E501

        :return: The host of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this LwM2MServerSecurityConfigDefault.

        Host for 'No Security' mode  # noqa: E501

        :param host: The host of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def port(self):
        """Gets the port of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Port for  Lwm2m Server: 'No Security' mode: Lwm2m Server or Bootstrap Server  # noqa: E501

        :return: The port of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this LwM2MServerSecurityConfigDefault.

        Port for  Lwm2m Server: 'No Security' mode: Lwm2m Server or Bootstrap Server  # noqa: E501

        :param port: The port of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def security_host(self):
        """Gets the security_host of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Host for 'Security' mode (DTLS)  # noqa: E501

        :return: The security_host of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: str
        """
        return self._security_host

    @security_host.setter
    def security_host(self, security_host):
        """Sets the security_host of this LwM2MServerSecurityConfigDefault.

        Host for 'Security' mode (DTLS)  # noqa: E501

        :param security_host: The security_host of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: str
        """

        self._security_host = security_host

    @property
    def security_port(self):
        """Gets the security_port of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Port for 'Security' mode (DTLS): Lwm2m Server or Bootstrap Server  # noqa: E501

        :return: The security_port of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._security_port

    @security_port.setter
    def security_port(self, security_port):
        """Sets the security_port of this LwM2MServerSecurityConfigDefault.

        Port for 'Security' mode (DTLS): Lwm2m Server or Bootstrap Server  # noqa: E501

        :param security_port: The security_port of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._security_port = security_port

    @property
    def client_hold_off_time(self):
        """Gets the client_hold_off_time of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Client Hold Off Time. The number of seconds to wait before initiating a Client Initiated Bootstrap once the LwM2M Client has determined it should initiate this bootstrap mode. (This information is relevant for use with a Bootstrap-Server only.)  # noqa: E501

        :return: The client_hold_off_time of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._client_hold_off_time

    @client_hold_off_time.setter
    def client_hold_off_time(self, client_hold_off_time):
        """Sets the client_hold_off_time of this LwM2MServerSecurityConfigDefault.

        Client Hold Off Time. The number of seconds to wait before initiating a Client Initiated Bootstrap once the LwM2M Client has determined it should initiate this bootstrap mode. (This information is relevant for use with a Bootstrap-Server only.)  # noqa: E501

        :param client_hold_off_time: The client_hold_off_time of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._client_hold_off_time = client_hold_off_time

    @property
    def server_public_key(self):
        """Gets the server_public_key of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Server Public Key for 'Security' mode (DTLS): RPK or X509. Format: base64 encoded  # noqa: E501

        :return: The server_public_key of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: str
        """
        return self._server_public_key

    @server_public_key.setter
    def server_public_key(self, server_public_key):
        """Sets the server_public_key of this LwM2MServerSecurityConfigDefault.

        Server Public Key for 'Security' mode (DTLS): RPK or X509. Format: base64 encoded  # noqa: E501

        :param server_public_key: The server_public_key of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: str
        """

        self._server_public_key = server_public_key

    @property
    def server_certificate(self):
        """Gets the server_certificate of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Server Public Key for 'Security' mode (DTLS): X509. Format: base64 encoded  # noqa: E501

        :return: The server_certificate of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: str
        """
        return self._server_certificate

    @server_certificate.setter
    def server_certificate(self, server_certificate):
        """Sets the server_certificate of this LwM2MServerSecurityConfigDefault.

        Server Public Key for 'Security' mode (DTLS): X509. Format: base64 encoded  # noqa: E501

        :param server_certificate: The server_certificate of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: str
        """

        self._server_certificate = server_certificate

    @property
    def bootstrap_server_account_timeout(self):
        """Gets the bootstrap_server_account_timeout of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Bootstrap Server Account Timeout (If the value is set to 0, or if this resource is not instantiated, the Bootstrap-Server Account lifetime is infinite.)  # noqa: E501

        :return: The bootstrap_server_account_timeout of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._bootstrap_server_account_timeout

    @bootstrap_server_account_timeout.setter
    def bootstrap_server_account_timeout(self, bootstrap_server_account_timeout):
        """Sets the bootstrap_server_account_timeout of this LwM2MServerSecurityConfigDefault.

        Bootstrap Server Account Timeout (If the value is set to 0, or if this resource is not instantiated, the Bootstrap-Server Account lifetime is infinite.)  # noqa: E501

        :param bootstrap_server_account_timeout: The bootstrap_server_account_timeout of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._bootstrap_server_account_timeout = bootstrap_server_account_timeout

    @property
    def lifetime(self):
        """Gets the lifetime of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        Specify the lifetime of the registration in seconds.  # noqa: E501

        :return: The lifetime of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._lifetime

    @lifetime.setter
    def lifetime(self, lifetime):
        """Sets the lifetime of this LwM2MServerSecurityConfigDefault.

        Specify the lifetime of the registration in seconds.  # noqa: E501

        :param lifetime: The lifetime of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._lifetime = lifetime

    @property
    def default_min_period(self):
        """Gets the default_min_period of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        The default value the LwM2M Client should use for the Minimum Period of an Observation in the absence of this parameter being included in an Observation. If this Resource doesn’t exist, the default value is 0.  # noqa: E501

        :return: The default_min_period of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: int
        """
        return self._default_min_period

    @default_min_period.setter
    def default_min_period(self, default_min_period):
        """Sets the default_min_period of this LwM2MServerSecurityConfigDefault.

        The default value the LwM2M Client should use for the Minimum Period of an Observation in the absence of this parameter being included in an Observation. If this Resource doesn’t exist, the default value is 0.  # noqa: E501

        :param default_min_period: The default_min_period of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: int
        """

        self._default_min_period = default_min_period

    @property
    def notif_if_disabled(self):
        """Gets the notif_if_disabled of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        If true, the LwM2M Client stores “Notify” operations to the LwM2M Server while the LwM2M Server account is disabled or the LwM2M Client is offline. After the LwM2M Server account is enabled or the LwM2M Client is online, the LwM2M Client reports the stored “Notify” operations to the Server. If false, the LwM2M Client discards all the “Notify” operations or temporarily disables the Observe function while the LwM2M Server is disabled or the LwM2M Client is offline. The default value is true.  # noqa: E501

        :return: The notif_if_disabled of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: bool
        """
        return self._notif_if_disabled

    @notif_if_disabled.setter
    def notif_if_disabled(self, notif_if_disabled):
        """Sets the notif_if_disabled of this LwM2MServerSecurityConfigDefault.

        If true, the LwM2M Client stores “Notify” operations to the LwM2M Server while the LwM2M Server account is disabled or the LwM2M Client is offline. After the LwM2M Server account is enabled or the LwM2M Client is online, the LwM2M Client reports the stored “Notify” operations to the Server. If false, the LwM2M Client discards all the “Notify” operations or temporarily disables the Observe function while the LwM2M Server is disabled or the LwM2M Client is offline. The default value is true.  # noqa: E501

        :param notif_if_disabled: The notif_if_disabled of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: bool
        """

        self._notif_if_disabled = notif_if_disabled

    @property
    def binding(self):
        """Gets the binding of this LwM2MServerSecurityConfigDefault.  # noqa: E501

        This Resource defines the transport binding configured for the LwM2M Client. If the LwM2M Client supports the binding specified in this Resource, the LwM2M Client MUST use that transport for the Current Binding Mode.  # noqa: E501

        :return: The binding of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :rtype: str
        """
        return self._binding

    @binding.setter
    def binding(self, binding):
        """Sets the binding of this LwM2MServerSecurityConfigDefault.

        This Resource defines the transport binding configured for the LwM2M Client. If the LwM2M Client supports the binding specified in this Resource, the LwM2M Client MUST use that transport for the Current Binding Mode.  # noqa: E501

        :param binding: The binding of this LwM2MServerSecurityConfigDefault.  # noqa: E501
        :type: str
        """

        self._binding = binding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LwM2MServerSecurityConfigDefault, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LwM2MServerSecurityConfigDefault):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.sms_provider_configuration import SmsProviderConfiguration  # noqa: F401,E501

class SmppSmsProviderConfiguration(SmsProviderConfiguration):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address_range': 'str',
        'bind_type': 'str',
        'coding_scheme': 'str',
        'destination_npi': 'str',
        'destination_ton': 'str',
        'host': 'str',
        'password': 'str',
        'port': 'int',
        'protocol_version': 'str',
        'service_type': 'str',
        'source_address': 'str',
        'source_npi': 'str',
        'source_ton': 'str',
        'system_id': 'str',
        'system_type': 'str'
    }
    if hasattr(SmsProviderConfiguration, "swagger_types"):
        swagger_types.update(SmsProviderConfiguration.swagger_types)

    attribute_map = {
        'address_range': 'addressRange',
        'bind_type': 'bindType',
        'coding_scheme': 'codingScheme',
        'destination_npi': 'destinationNpi',
        'destination_ton': 'destinationTon',
        'host': 'host',
        'password': 'password',
        'port': 'port',
        'protocol_version': 'protocolVersion',
        'service_type': 'serviceType',
        'source_address': 'sourceAddress',
        'source_npi': 'sourceNpi',
        'source_ton': 'sourceTon',
        'system_id': 'systemId',
        'system_type': 'systemType'
    }
    if hasattr(SmsProviderConfiguration, "attribute_map"):
        attribute_map.update(SmsProviderConfiguration.attribute_map)

    def __init__(self, address_range=None, bind_type=None, coding_scheme=None, destination_npi=None, destination_ton=None, host=None, password=None, port=None, protocol_version=None, service_type=None, source_address=None, source_npi=None, source_ton=None, system_id=None, system_type=None, *args, **kwargs):  # noqa: E501
        """SmppSmsProviderConfiguration - a model defined in Swagger"""  # noqa: E501
        self._address_range = None
        self._bind_type = None
        self._coding_scheme = None
        self._destination_npi = None
        self._destination_ton = None
        self._host = None
        self._password = None
        self._port = None
        self._protocol_version = None
        self._service_type = None
        self._source_address = None
        self._source_npi = None
        self._source_ton = None
        self._system_id = None
        self._system_type = None
        self.discriminator = None
        if address_range is not None:
            self.address_range = address_range
        if bind_type is not None:
            self.bind_type = bind_type
        if coding_scheme is not None:
            self.coding_scheme = coding_scheme
        if destination_npi is not None:
            self.destination_npi = destination_npi
        if destination_ton is not None:
            self.destination_ton = destination_ton
        self.host = host
        self.password = password
        self.port = port
        self.protocol_version = protocol_version
        if service_type is not None:
            self.service_type = service_type
        if source_address is not None:
            self.source_address = source_address
        if source_npi is not None:
            self.source_npi = source_npi
        if source_ton is not None:
            self.source_ton = source_ton
        self.system_id = system_id
        if system_type is not None:
            self.system_type = system_type
        SmsProviderConfiguration.__init__(self, *args, **kwargs)

    @property
    def address_range(self):
        """Gets the address_range of this SmppSmsProviderConfiguration.  # noqa: E501

        Address range  # noqa: E501

        :return: The address_range of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._address_range

    @address_range.setter
    def address_range(self, address_range):
        """Sets the address_range of this SmppSmsProviderConfiguration.

        Address range  # noqa: E501

        :param address_range: The address_range of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._address_range = address_range

    @property
    def bind_type(self):
        """Gets the bind_type of this SmppSmsProviderConfiguration.  # noqa: E501

        TX - Transmitter, RX - Receiver, TRX - Transciever. By default TX is used  # noqa: E501

        :return: The bind_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._bind_type

    @bind_type.setter
    def bind_type(self, bind_type):
        """Sets the bind_type of this SmppSmsProviderConfiguration.

        TX - Transmitter, RX - Receiver, TRX - Transciever. By default TX is used  # noqa: E501

        :param bind_type: The bind_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """
        allowed_values = ["RX", "TRX", "TX"]  # noqa: E501
        if bind_type not in allowed_values:
            raise ValueError(
                "Invalid value for `bind_type` ({0}), must be one of {1}"  # noqa: E501
                .format(bind_type, allowed_values)
            )

        self._bind_type = bind_type

    @property
    def coding_scheme(self):
        """Gets the coding_scheme of this SmppSmsProviderConfiguration.  # noqa: E501

        0 - SMSC Default Alphabet (ASCII for short and long code and to GSM for toll-free, used as default) 1 - IA5 (ASCII for short and long code, Latin 9 for toll-free (ISO-8859-9)) 2 - Octet Unspecified (8-bit binary) 3 - Latin 1 (ISO-8859-1) 4 - Octet Unspecified (8-bit binary) 5 - JIS (X 0208-1990) 6 - Cyrillic (ISO-8859-5) 7 - Latin/Hebrew (ISO-8859-8) 8 - UCS2/UTF-16 (ISO/IEC-10646) 9 - Pictogram Encoding 10 - Music Codes (ISO-2022-JP) 13 - Extended Kanji JIS (X 0212-1990) 14 - Korean Graphic Character Set (KS C 5601/KS X 1001)  # noqa: E501

        :return: The coding_scheme of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._coding_scheme

    @coding_scheme.setter
    def coding_scheme(self, coding_scheme):
        """Sets the coding_scheme of this SmppSmsProviderConfiguration.

        0 - SMSC Default Alphabet (ASCII for short and long code and to GSM for toll-free, used as default) 1 - IA5 (ASCII for short and long code, Latin 9 for toll-free (ISO-8859-9)) 2 - Octet Unspecified (8-bit binary) 3 - Latin 1 (ISO-8859-1) 4 - Octet Unspecified (8-bit binary) 5 - JIS (X 0208-1990) 6 - Cyrillic (ISO-8859-5) 7 - Latin/Hebrew (ISO-8859-8) 8 - UCS2/UTF-16 (ISO/IEC-10646) 9 - Pictogram Encoding 10 - Music Codes (ISO-2022-JP) 13 - Extended Kanji JIS (X 0212-1990) 14 - Korean Graphic Character Set (KS C 5601/KS X 1001)  # noqa: E501

        :param coding_scheme: The coding_scheme of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._coding_scheme = coding_scheme

    @property
    def destination_npi(self):
        """Gets the destination_npi of this SmppSmsProviderConfiguration.  # noqa: E501

        Destination NPI (Numbering Plan Identification). 0 by default. 0 - Unknown 1 - ISDN/telephone numbering plan (E163/E164) 3 - Data numbering plan (X.121) 4 - Telex numbering plan (F.69) 6 - Land Mobile (E.212) =6 8 - National numbering plan 9 - Private numbering plan 10 - ERMES numbering plan (ETSI DE/PS 3 01-3) 13 - Internet (IP) 18 - WAP Client Id (to be defined by WAP Forum)  # noqa: E501

        :return: The destination_npi of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._destination_npi

    @destination_npi.setter
    def destination_npi(self, destination_npi):
        """Sets the destination_npi of this SmppSmsProviderConfiguration.

        Destination NPI (Numbering Plan Identification). 0 by default. 0 - Unknown 1 - ISDN/telephone numbering plan (E163/E164) 3 - Data numbering plan (X.121) 4 - Telex numbering plan (F.69) 6 - Land Mobile (E.212) =6 8 - National numbering plan 9 - Private numbering plan 10 - ERMES numbering plan (ETSI DE/PS 3 01-3) 13 - Internet (IP) 18 - WAP Client Id (to be defined by WAP Forum)  # noqa: E501

        :param destination_npi: The destination_npi of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._destination_npi = destination_npi

    @property
    def destination_ton(self):
        """Gets the destination_ton of this SmppSmsProviderConfiguration.  # noqa: E501

        Destination TON (Type of Number). 5 by default. 0 - Unknown 1 - International 2 - National 3 - Network Specific 4 - Subscriber Number 5 - Alphanumeric 6 - Abbreviated  # noqa: E501

        :return: The destination_ton of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._destination_ton

    @destination_ton.setter
    def destination_ton(self, destination_ton):
        """Sets the destination_ton of this SmppSmsProviderConfiguration.

        Destination TON (Type of Number). 5 by default. 0 - Unknown 1 - International 2 - National 3 - Network Specific 4 - Subscriber Number 5 - Alphanumeric 6 - Abbreviated  # noqa: E501

        :param destination_ton: The destination_ton of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._destination_ton = destination_ton

    @property
    def host(self):
        """Gets the host of this SmppSmsProviderConfiguration.  # noqa: E501

        SMPP host  # noqa: E501

        :return: The host of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this SmppSmsProviderConfiguration.

        SMPP host  # noqa: E501

        :param host: The host of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """
        if host is None:
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def password(self):
        """Gets the password of this SmppSmsProviderConfiguration.  # noqa: E501

        Password  # noqa: E501

        :return: The password of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this SmppSmsProviderConfiguration.

        Password  # noqa: E501

        :param password: The password of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def port(self):
        """Gets the port of this SmppSmsProviderConfiguration.  # noqa: E501

        SMPP port  # noqa: E501

        :return: The port of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this SmppSmsProviderConfiguration.

        SMPP port  # noqa: E501

        :param port: The port of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: int
        """
        if port is None:
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def protocol_version(self):
        """Gets the protocol_version of this SmppSmsProviderConfiguration.  # noqa: E501

        SMPP version  # noqa: E501

        :return: The protocol_version of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._protocol_version

    @protocol_version.setter
    def protocol_version(self, protocol_version):
        """Sets the protocol_version of this SmppSmsProviderConfiguration.

        SMPP version  # noqa: E501

        :param protocol_version: The protocol_version of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """
        if protocol_version is None:
            raise ValueError("Invalid value for `protocol_version`, must not be `None`")  # noqa: E501
        allowed_values = ["3.3", "3.4"]  # noqa: E501
        if protocol_version not in allowed_values:
            raise ValueError(
                "Invalid value for `protocol_version` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol_version, allowed_values)
            )

        self._protocol_version = protocol_version

    @property
    def service_type(self):
        """Gets the service_type of this SmppSmsProviderConfiguration.  # noqa: E501

        Service type  # noqa: E501

        :return: The service_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._service_type

    @service_type.setter
    def service_type(self, service_type):
        """Sets the service_type of this SmppSmsProviderConfiguration.

        Service type  # noqa: E501

        :param service_type: The service_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._service_type = service_type

    @property
    def source_address(self):
        """Gets the source_address of this SmppSmsProviderConfiguration.  # noqa: E501

        Source address  # noqa: E501

        :return: The source_address of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._source_address

    @source_address.setter
    def source_address(self, source_address):
        """Sets the source_address of this SmppSmsProviderConfiguration.

        Source address  # noqa: E501

        :param source_address: The source_address of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._source_address = source_address

    @property
    def source_npi(self):
        """Gets the source_npi of this SmppSmsProviderConfiguration.  # noqa: E501

        Source NPI (Numbering Plan Identification). Needed is source address is set. 0 by default. 0 - Unknown 1 - ISDN/telephone numbering plan (E163/E164) 3 - Data numbering plan (X.121) 4 - Telex numbering plan (F.69) 6 - Land Mobile (E.212) =6 8 - National numbering plan 9 - Private numbering plan 10 - ERMES numbering plan (ETSI DE/PS 3 01-3) 13 - Internet (IP) 18 - WAP Client Id (to be defined by WAP Forum)  # noqa: E501

        :return: The source_npi of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._source_npi

    @source_npi.setter
    def source_npi(self, source_npi):
        """Sets the source_npi of this SmppSmsProviderConfiguration.

        Source NPI (Numbering Plan Identification). Needed is source address is set. 0 by default. 0 - Unknown 1 - ISDN/telephone numbering plan (E163/E164) 3 - Data numbering plan (X.121) 4 - Telex numbering plan (F.69) 6 - Land Mobile (E.212) =6 8 - National numbering plan 9 - Private numbering plan 10 - ERMES numbering plan (ETSI DE/PS 3 01-3) 13 - Internet (IP) 18 - WAP Client Id (to be defined by WAP Forum)  # noqa: E501

        :param source_npi: The source_npi of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._source_npi = source_npi

    @property
    def source_ton(self):
        """Gets the source_ton of this SmppSmsProviderConfiguration.  # noqa: E501

        Source TON (Type of Number). Needed is source address is set. 5 by default. 0 - Unknown 1 - International 2 - National 3 - Network Specific 4 - Subscriber Number 5 - Alphanumeric 6 - Abbreviated  # noqa: E501

        :return: The source_ton of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._source_ton

    @source_ton.setter
    def source_ton(self, source_ton):
        """Sets the source_ton of this SmppSmsProviderConfiguration.

        Source TON (Type of Number). Needed is source address is set. 5 by default. 0 - Unknown 1 - International 2 - National 3 - Network Specific 4 - Subscriber Number 5 - Alphanumeric 6 - Abbreviated  # noqa: E501

        :param source_ton: The source_ton of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._source_ton = source_ton

    @property
    def system_id(self):
        """Gets the system_id of this SmppSmsProviderConfiguration.  # noqa: E501

        System ID  # noqa: E501

        :return: The system_id of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this SmppSmsProviderConfiguration.

        System ID  # noqa: E501

        :param system_id: The system_id of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """
        if system_id is None:
            raise ValueError("Invalid value for `system_id`, must not be `None`")  # noqa: E501

        self._system_id = system_id

    @property
    def system_type(self):
        """Gets the system_type of this SmppSmsProviderConfiguration.  # noqa: E501

        System type  # noqa: E501

        :return: The system_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._system_type

    @system_type.setter
    def system_type(self, system_type):
        """Sets the system_type of this SmppSmsProviderConfiguration.

        System type  # noqa: E501

        :param system_type: The system_type of this SmppSmsProviderConfiguration.  # noqa: E501
        :type: str
        """

        self._system_type = system_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SmppSmsProviderConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmppSmsProviderConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class LwM2mResourceObserve(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'observe': 'bool',
        'attribute': 'bool',
        'telemetry': 'bool',
        'key_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'observe': 'observe',
        'attribute': 'attribute',
        'telemetry': 'telemetry',
        'key_name': 'keyName'
    }

    def __init__(self, id=None, name=None, observe=None, attribute=None, telemetry=None, key_name=None):  # noqa: E501
        """LwM2mResourceObserve - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._observe = None
        self._attribute = None
        self._telemetry = None
        self._key_name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if observe is not None:
            self.observe = observe
        if attribute is not None:
            self.attribute = attribute
        if telemetry is not None:
            self.telemetry = telemetry
        if key_name is not None:
            self.key_name = key_name

    @property
    def id(self):
        """Gets the id of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe id.  # noqa: E501

        :return: The id of this LwM2mResourceObserve.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LwM2mResourceObserve.

        LwM2M Resource Observe id.  # noqa: E501

        :param id: The id of this LwM2mResourceObserve.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe name.  # noqa: E501

        :return: The name of this LwM2mResourceObserve.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LwM2mResourceObserve.

        LwM2M Resource Observe name.  # noqa: E501

        :param name: The name of this LwM2mResourceObserve.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def observe(self):
        """Gets the observe of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe observe.  # noqa: E501

        :return: The observe of this LwM2mResourceObserve.  # noqa: E501
        :rtype: bool
        """
        return self._observe

    @observe.setter
    def observe(self, observe):
        """Sets the observe of this LwM2mResourceObserve.

        LwM2M Resource Observe observe.  # noqa: E501

        :param observe: The observe of this LwM2mResourceObserve.  # noqa: E501
        :type: bool
        """

        self._observe = observe

    @property
    def attribute(self):
        """Gets the attribute of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe attribute.  # noqa: E501

        :return: The attribute of this LwM2mResourceObserve.  # noqa: E501
        :rtype: bool
        """
        return self._attribute

    @attribute.setter
    def attribute(self, attribute):
        """Sets the attribute of this LwM2mResourceObserve.

        LwM2M Resource Observe attribute.  # noqa: E501

        :param attribute: The attribute of this LwM2mResourceObserve.  # noqa: E501
        :type: bool
        """

        self._attribute = attribute

    @property
    def telemetry(self):
        """Gets the telemetry of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe telemetry.  # noqa: E501

        :return: The telemetry of this LwM2mResourceObserve.  # noqa: E501
        :rtype: bool
        """
        return self._telemetry

    @telemetry.setter
    def telemetry(self, telemetry):
        """Sets the telemetry of this LwM2mResourceObserve.

        LwM2M Resource Observe telemetry.  # noqa: E501

        :param telemetry: The telemetry of this LwM2mResourceObserve.  # noqa: E501
        :type: bool
        """

        self._telemetry = telemetry

    @property
    def key_name(self):
        """Gets the key_name of this LwM2mResourceObserve.  # noqa: E501

        LwM2M Resource Observe key name.  # noqa: E501

        :return: The key_name of this LwM2mResourceObserve.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this LwM2mResourceObserve.

        LwM2M Resource Observe key name.  # noqa: E501

        :param key_name: The key_name of this LwM2mResourceObserve.  # noqa: E501
        :type: str
        """

        self._key_name = key_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LwM2mResourceObserve, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LwM2mResourceObserve):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
